==> speech-analytic-testing_0.22.0_database.tar.gz: database/mssql/procedures/GetCleanerData.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO


CREATE PROCEDURE [dbo].[GetCleanerData] (
@VCC VARCHAR(50),
@DAYS INT
)

AS
BEGIN
	SET NOCOUNT ON
      
				      --BUSCA REGISTROS PARA ELIMINARLOS DE LA BASE DE DATOS POR CADA VCC
				      
				
					   DECLARE @NOW VARCHAR(15) = CONVERT(VARCHAR,GETUTCDATE(),23)
				
					   CREATE TABLE #ProcessToDelete(
					   [Name] VARCHAR(50)
					   )
				       
				       CREATE TABLE #ProcessAsyncToDelete(
				       [ProcessId]  VARCHAR(50)
				       )
				       
				       DECLARE @FindInEvaluationPlan TABLE (
				        [Name] VARCHAR(50)
				       )
				       
				       DECLARE @FindInStudy TABLE (
				        [Name] VARCHAR(50)
				       )	
				       
					   DECLARE @EvaluationPlan TABLE(
					   [ID]      VARCHAR(50)
					   )
					   DECLARE @Study TABLE(
					   [Name]    VARCHAR(50)
					   )

					   CREATE TABLE #AudioToDelete(
					   [ID]       VARCHAR(100),
					   [FileName] VARCHAR(700)
					   )
					   
					   CREATE TABLE #AsyncInteractionToDelete(
					   [ID]       VARCHAR(250),
					   [FileName] VARCHAR(250),
					   [ViewFileName] VARCHAR(250)
					   )
					   
					 --BUSCAR PLANES
					 
					  INSERT INTO @EvaluationPlan
					  SELECT 
							[ID]
					  FROM  [dbo].[EvaluationPlan] (NOLOCK) 
					  WHERE [Instance] = @VCC 
							AND DATEDIFF(DAY,CONVERT(VARCHAR,[CreatedDate],23),@NOW) > @DAYS

					--BUSCAR ESTUDIOS
					
					INSERT INTO @Study
					SELECT 
					    
						  [Name]
				    FROM  [dbo].[Study] (NOLOCK)
					WHERE [VCC] = @VCC
					      AND DATEDIFF(DAY,CONVERT(VARCHAR,[CreatedDate],23),@NOW) > @DAYS
					      
					  
					--BUSCAR PROCESOS DE PLANES
					
			       INSERT INTO #ProcessToDelete 
				   SELECT 
					     P.[Name]
				   FROM  [dbo].[Process] P (NOLOCK) 
				   JOIN  [dbo].[EvaluationPlan] EP (NOLOCK)
				         ON (P.[VCC] = EP.[Instance] AND P.[Name] = EP.[ProcessId] )
				   WHERE P.[VCC] = @VCC 
				         AND EP.[ID] IN (SELECT [ID] FROM @EvaluationPlan)
				         
				         
				    --BUSCAR SI SE ESTA UTILIZANDO EN PLANES MAS RECIENTES
				    
				    INSERT INTO @FindInEvaluationPlan
				    SELECT 
				         DISTINCT [ProcessId]
				    FROM [dbo].[EvaluationPlan] (NOLOCK)
				    WHERE [Instance] = @VCC 
				          AND [ProcessId] IN (SELECT [Name] FROM #ProcessToDelete)
				          AND DATEDIFF(DAY,CONVERT(VARCHAR,[CreatedDate],23),@NOW) <= @DAYS
				          
	

					--BUSCAR PROCESOS DE ESTUDIOS
					
			       INSERT INTO #ProcessToDelete 
				   SELECT 
					     P.[Name]
				   FROM  [dbo].[Process] P (NOLOCK) 
				   JOIN  [dbo].[Study] S (NOLOCK)
				         ON (P.[VCC] = S.[VCC] AND P.[Name] = S.[ProcessId] )
				   WHERE P.[VCC] = @VCC 
				         AND S.[Name] IN (SELECT [Name] FROM @Study)
				         

				    --BUSCAR SI SE ESTA UTILIZANDO EN ESTUDIOS MAS RECIENTES
				    
				    INSERT INTO @FindInStudy
				    SELECT 
				         DISTINCT [ProcessId]
				    FROM [dbo].[Study] (NOLOCK)
				    WHERE [VCC] = @VCC 
				          AND [ProcessId] IN (SELECT [Name] FROM #ProcessToDelete)
				          AND DATEDIFF(DAY,CONVERT(VARCHAR,[CreatedDate],23),@NOW) <= @DAYS
				          
				     
				          
 					--BUSCAR PROCESOS QUE NO ESTEN ASIGNADOS
					
			       INSERT INTO #ProcessToDelete 
				   SELECT 
					     [Name]
				   FROM  [dbo].[Process] (NOLOCK) 
				   WHERE [VCC] = @VCC 
				         AND [Name] NOT IN (SELECT [Name] FROM #ProcessToDelete)
				         AND DATEDIFF(DAY,CONVERT(VARCHAR,[CreatedDate],23),@NOW) > @DAYS
				         
				         
				    --ELIMINAR DE #ProcessToDelete LOS PROCESOS QUE SE ASIGNARON MAS DE UNA VEZ Y RECIENTEMENTE
				    
				     DELETE FROM #ProcessToDelete WHERE [Name] IN (SELECT [Name] FROM @FindInEvaluationPlan)
				     DELETE FROM #ProcessToDelete WHERE [Name] IN (SELECT [Name] FROM @FindInStudy)  
				     

                    --BUSCAR AUDIOS DE LOS PROCESOS QUE QUEDARON PARA SER ELIMINADOS
                    
                    INSERT INTO #AudioToDelete
                    SELECT A.[ID],A.[FileName] FROM [dbo].[Audio] A (NOLOCK)
                    JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
                    ON (A.[VCC] = PA.[VCC] AND A.[ID] = PA.[AudioId])
                    WHERE A.[VCC] = @VCC 
                          AND  PA.[ProcessId] IN (SELECT [Name] FROM #ProcessToDelete)
                    
                    --BUSCAR Y QUITAR LOS AUDIOS QUE FUERON ASIGNADOS A UN NUEVO PROCESO
                    
                     DELETE FROM #AudioToDelete 
                     WHERE [ID] IN (
                     SELECT [ID] FROM [dbo].[Audio] A (NOLOCK) 
                     JOIN [dbo].[ProcessAudio] PA (NOLOCK)
                     ON (A.[VCC] = PA.[VCC] AND A.[ID] = PA.[AudioId])
                     WHERE A.[VCC] = @VCC
                          AND  PA.[ProcessId] NOT IN (SELECT [Name] FROM #ProcessToDelete)
                          AND DATEDIFF(DAY,CONVERT(VARCHAR,PA.[CreatedDate],23),@NOW) <= @DAYS
                     )
                     
                     
                    --RESETEAR VARIABLES TEMPORALES PARA UTILIZARLAS CON PROCESOS ASINCRONOS
                    
                    DELETE FROM @FindInEvaluationPlan
                    DELETE FROM @FindInStudy
                    
                    
                    --BUSCAR PROCESOS ASINCRONOS DE PLANES
                     INSERT INTO #ProcessAsyncToDelete
                     SELECT 
					     P.[ProcessId]
				     FROM  [dbo].[ProcessAsyncInteraction] P (NOLOCK) 
				     JOIN  [dbo].[EvaluationPlan] EP (NOLOCK)
				         ON (P.[VCC] = EP.[Instance] AND P.[ProcessId] = EP.[ProcessId] )
				     WHERE P.[VCC] = @VCC 
				         AND EP.[ID] IN (SELECT [ID] FROM @EvaluationPlan)    
				         
				         
				    --BUSCAR PROCESOS ASINCRONOS SI SE ESTA UTILIZANDO EN PLANES MAS RECIENTES
				    
				    INSERT INTO @FindInEvaluationPlan
				    SELECT 
				         [ProcessId]
				    FROM  [dbo].[EvaluationPlan] (NOLOCK)
				    WHERE [Instance] = @VCC 
				          AND [ProcessId] IN (SELECT [ProcessId] FROM #ProcessAsyncToDelete)
				          AND DATEDIFF(DAY,CONVERT(VARCHAR,[CreatedDate],23),@NOW) <= @DAYS
				          

					--BUSCAR PROCESOS ASINCRONOS DE ESTUDIOS
					
			       INSERT INTO #ProcessAsyncToDelete 
				   SELECT 
					     P.[ProcessId]
				   FROM  [dbo].[ProcessAsyncInteraction] P (NOLOCK) 
				   JOIN  [dbo].[Study] S (NOLOCK)
				         ON (P.[VCC] = S.[VCC] AND P.[ProcessId] = S.[ProcessId] )
				   WHERE P.[VCC] = @VCC 
				         AND S.[Name] IN (SELECT [Name] FROM @Study)
				         
				         
				    --BUSCAR PROCESOS ASINCRONOS SI SE ESTA UTILIZANDO EN ESTUDIOS MAS RECIENTES
				    
				    INSERT INTO @FindInStudy
				    SELECT 
				         DISTINCT [ProcessId]
				    FROM [dbo].[Study]  (NOLOCK)
				    WHERE [VCC] = @VCC 
				          AND [ProcessId] IN (SELECT [ProcessId] FROM #ProcessAsyncToDelete)
				          AND DATEDIFF(DAY,CONVERT(VARCHAR,[CreatedDate],23),@NOW) <= @DAYS
				          
				     
 					--BUSCAR PROCESOS ASINCRONOS QUE NO ESTEN ASIGNADOS A PLANES NI ESTUDIOS
					
			       INSERT INTO #ProcessAsyncToDelete 
				   SELECT 
					     [ProcessId]
				   FROM  [dbo].[ProcessAsyncInteraction] (NOLOCK) 
				   WHERE [VCC] = @VCC 
				         AND [ProcessId] NOT IN (SELECT [ProcessId] FROM #ProcessAsyncToDelete)
				         AND DATEDIFF(DAY,CONVERT(VARCHAR,[CreatedDate],23),@NOW) > @DAYS
				         
				    --ELIMINAR DE #ProcessAsyncToDelete LOS PROCESOS QUE SE ASIGNARON MAS DE UNA VEZ Y RECIENTEMENTE
				    
				     DELETE FROM #ProcessAsyncToDelete WHERE [ProcessId] IN (SELECT [ProcessId] FROM @FindInEvaluationPlan)
				     DELETE FROM #ProcessAsyncToDelete WHERE [ProcessId] IN (SELECT [ProcessId] FROM @FindInStudy)  
				     

                    --BUSCAR INTERACCIONES ASINCRONAS DE LOS PROCESOS QUE QUEDARON PARA SER ELIMINADOS
                    
                    INSERT INTO #AsyncInteractionToDelete
                    SELECT 
                          A.[ID],
                          A.[FileName],
                          A.[ViewFileName]
                    FROM [dbo].[AsyncInteraction] A (NOLOCK)
                    JOIN [dbo].[ProcessAsyncInteraction] PA (NOLOCK) 
                    ON (A.[VCC] = PA.[VCC] AND A.[ID] = PA.[InteractionId])
                    WHERE A.[VCC] = @VCC 
                          AND  PA.[ProcessId] IN (SELECT [ProcessId] FROM #ProcessAsyncToDelete)
                    
                    --BUSCAR Y QUITAR LAS INTERACCIONES ASINCRONAS QUE FUERON ASIGNADAS A UN NUEVO PROCESO
                    
                     DELETE FROM #AsyncInteractionToDelete 
                     WHERE [ID] IN (
                     SELECT [ID] FROM [dbo].[AsyncInteraction] A (NOLOCK) 
                     JOIN [dbo].[ProcessAsyncInteraction] PA (NOLOCK)
                     ON (A.[VCC] = PA.[VCC] AND A.[ID] = PA.[InteractionId])
                     WHERE A.[VCC] = @VCC
                          AND  PA.[ProcessId] NOT IN (SELECT [ProcessId] FROM #ProcessAsyncToDelete)
                          AND DATEDIFF(DAY,CONVERT(VARCHAR,PA.[CreatedDate],23),@NOW) <= @DAYS
                     )
                     
                     
                    --LISTAR LOS RESULTADOS FINALES
                    
                    SELECT [ID] 'id'     FROM @EvaluationPlan
                    
                    SELECT [Name] 'name' FROM @Study
                  
					SELECT DISTINCT [Name] 'name' FROM #ProcessToDelete
					
					SELECT DISTINCT [ProcessId] 'processId' FROM #ProcessAsyncToDelete
					
					SELECT DISTINCT [ID] 'id',[FileName] 'fileName' FROM #AudioToDelete
					
					SELECT DISTINCT [ID] 'id',[FileName] 'fileName',[ViewFileName] 'viewFileName' FROM #AsyncInteractionToDelete
					
					
					--ELIMINAR LAS TABLAS TEMPORALES
					
					DROP TABLE #ProcessToDelete
					DROP TABLE #AudioToDelete
					DROP TABLE #ProcessAsyncToDelete
					DROP TABLE #AsyncInteractionToDelete
	  
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO

==> speech-analytic-testing_0.23.0_database.tar.gz: database/mssql/procedures/GetCleanerData.sql <==
SET QUOTED_IDENTIFIER ON 
GO
SET ANSI_NULLS ON 
GO


CREATE PROCEDURE [dbo].[GetCleanerData] (
@VCC VARCHAR(50),
@DAYS INT
)

AS
BEGIN
	SET NOCOUNT ON
      
				      --BUSCA REGISTROS PARA ELIMINARLOS DE LA BASE DE DATOS POR CADA VCC
				      
				
					   DECLARE @NOW VARCHAR(15) = CONVERT(VARCHAR,GETUTCDATE(),23)
				
					   CREATE TABLE #ProcessToDelete(
					   [Name] VARCHAR(50)
					   )
				       
				       CREATE TABLE #ProcessAsyncToDelete(
				       [ProcessId]  VARCHAR(50)
				       )
				       
				       DECLARE @FindInEvaluationPlan TABLE (
				        [Name] VARCHAR(50)
				       )
				       
				       DECLARE @FindInStudy TABLE (
				        [Name] VARCHAR(50)
				       )	
				       
					   DECLARE @EvaluationPlan TABLE(
					   [ID]      VARCHAR(50)
					   )
					   DECLARE @Study TABLE(
					   [Name]    VARCHAR(50)
					   )

					   CREATE TABLE #AudioToDelete(
					   [ID]       VARCHAR(100),
					   [FileName] VARCHAR(700)
					   )
					   
					   CREATE TABLE #AsyncInteractionToDelete(
					   [ID]       VARCHAR(250)
					   )
					   
					 --BUSCAR PLANES
					 
					  INSERT INTO @EvaluationPlan
					  SELECT 
							[ID]
					  FROM  [dbo].[EvaluationPlan] (NOLOCK) 
					  WHERE [Instance] = @VCC 
							AND DATEDIFF(DAY,CONVERT(VARCHAR,[CreatedDate],23),@NOW) > @DAYS

					--BUSCAR ESTUDIOS
					
					INSERT INTO @Study
					SELECT 
					    
						  [Name]
				    FROM  [dbo].[Study] (NOLOCK)
					WHERE [VCC] = @VCC
					      AND DATEDIFF(DAY,CONVERT(VARCHAR,[CreatedDate],23),@NOW) > @DAYS
					      
					  
					--BUSCAR PROCESOS DE PLANES
					
			       INSERT INTO #ProcessToDelete 
				   SELECT 
					     P.[Name]
				   FROM  [dbo].[Process] P (NOLOCK) 
				   JOIN  [dbo].[EvaluationPlan] EP (NOLOCK)
				         ON (P.[VCC] = EP.[Instance] AND P.[Name] = EP.[ProcessId] )
				   WHERE P.[VCC] = @VCC 
				         AND EP.[ID] IN (SELECT [ID] FROM @EvaluationPlan)
				         
				         
				    --BUSCAR SI SE ESTA UTILIZANDO EN PLANES MAS RECIENTES
				    
				    INSERT INTO @FindInEvaluationPlan
				    SELECT 
				         DISTINCT [ProcessId]
				    FROM [dbo].[EvaluationPlan] (NOLOCK)
				    WHERE [Instance] = @VCC 
				          AND [ProcessId] IN (SELECT [Name] FROM #ProcessToDelete)
				          AND DATEDIFF(DAY,CONVERT(VARCHAR,[CreatedDate],23),@NOW) <= @DAYS
				          
	

					--BUSCAR PROCESOS DE ESTUDIOS
					
			       INSERT INTO #ProcessToDelete 
				   SELECT 
					     P.[Name]
				   FROM  [dbo].[Process] P (NOLOCK) 
				   JOIN  [dbo].[Study] S (NOLOCK)
				         ON (P.[VCC] = S.[VCC] AND P.[Name] = S.[ProcessId] )
				   WHERE P.[VCC] = @VCC 
				         AND S.[Name] IN (SELECT [Name] FROM @Study)
				         

				    --BUSCAR SI SE ESTA UTILIZANDO EN ESTUDIOS MAS RECIENTES
				    
				    INSERT INTO @FindInStudy
				    SELECT 
				         DISTINCT [ProcessId]
				    FROM [dbo].[Study] (NOLOCK)
				    WHERE [VCC] = @VCC 
				          AND [ProcessId] IN (SELECT [Name] FROM #ProcessToDelete)
				          AND DATEDIFF(DAY,CONVERT(VARCHAR,[CreatedDate],23),@NOW) <= @DAYS
				          
				     
				          
 					--BUSCAR PROCESOS QUE NO ESTEN ASIGNADOS
					
			       INSERT INTO #ProcessToDelete 
				   SELECT 
					     [Name]
				   FROM  [dbo].[Process] (NOLOCK) 
				   WHERE [VCC] = @VCC 
				         AND [Name] NOT IN (SELECT [Name] FROM #ProcessToDelete)
				         AND DATEDIFF(DAY,CONVERT(VARCHAR,[CreatedDate],23),@NOW) > @DAYS
				         
				         
				    --ELIMINAR DE #ProcessToDelete LOS PROCESOS QUE SE ASIGNARON MAS DE UNA VEZ Y RECIENTEMENTE
				    
				     DELETE FROM #ProcessToDelete WHERE [Name] IN (SELECT [Name] FROM @FindInEvaluationPlan)
				     DELETE FROM #ProcessToDelete WHERE [Name] IN (SELECT [Name] FROM @FindInStudy)  
				     

                    --BUSCAR AUDIOS DE LOS PROCESOS QUE QUEDARON PARA SER ELIMINADOS
                    
                    INSERT INTO #AudioToDelete
                    SELECT A.[ID],A.[FileName] FROM [dbo].[Audio] A (NOLOCK)
                    JOIN [dbo].[ProcessAudio] PA (NOLOCK) 
                    ON (A.[VCC] = PA.[VCC] AND A.[ID] = PA.[AudioId])
                    WHERE A.[VCC] = @VCC 
                          AND  PA.[ProcessId] IN (SELECT [Name] FROM #ProcessToDelete)
                    
                    --BUSCAR Y QUITAR LOS AUDIOS QUE FUERON ASIGNADOS A UN NUEVO PROCESO
                    
                     DELETE FROM #AudioToDelete 
                     WHERE [ID] IN (
                     SELECT [ID] FROM [dbo].[Audio] A (NOLOCK) 
                     JOIN [dbo].[ProcessAudio] PA (NOLOCK)
                     ON (A.[VCC] = PA.[VCC] AND A.[ID] = PA.[AudioId])
                     WHERE A.[VCC] = @VCC
                          AND  PA.[ProcessId] NOT IN (SELECT [Name] FROM #ProcessToDelete)
                          AND DATEDIFF(DAY,CONVERT(VARCHAR,PA.[CreatedDate],23),@NOW) <= @DAYS
                     )
                     
                     
                    --RESETEAR VARIABLES TEMPORALES PARA UTILIZARLAS CON PROCESOS ASINCRONOS
                    
                    DELETE FROM @FindInEvaluationPlan
                    DELETE FROM @FindInStudy
                    
                    
                    --BUSCAR PROCESOS ASINCRONOS DE PLANES
                     INSERT INTO #ProcessAsyncToDelete
                     SELECT 
					     P.[ProcessId]
				     FROM  [dbo].[ProcessAsyncInteraction] P (NOLOCK) 
				     JOIN  [dbo].[EvaluationPlan] EP (NOLOCK)
				         ON (P.[VCC] = EP.[Instance] AND P.[ProcessId] = EP.[ProcessId] )
				     WHERE P.[VCC] = @VCC 
				         AND EP.[ID] IN (SELECT [ID] FROM @EvaluationPlan)    
				         
				         
				    --BUSCAR PROCESOS ASINCRONOS SI SE ESTA UTILIZANDO EN PLANES MAS RECIENTES
				    
				    INSERT INTO @FindInEvaluationPlan
				    SELECT 
				         [ProcessId]
				    FROM  [dbo].[EvaluationPlan] (NOLOCK)
				    WHERE [Instance] = @VCC 
				          AND [ProcessId] IN (SELECT [ProcessId] FROM #ProcessAsyncToDelete)
				          AND DATEDIFF(DAY,CONVERT(VARCHAR,[CreatedDate],23),@NOW) <= @DAYS
				          

					--BUSCAR PROCESOS ASINCRONOS DE ESTUDIOS
					
			       INSERT INTO #ProcessAsyncToDelete 
				   SELECT 
					     P.[ProcessId]
				   FROM  [dbo].[ProcessAsyncInteraction] P (NOLOCK) 
				   JOIN  [dbo].[Study] S (NOLOCK)
				         ON (P.[VCC] = S.[VCC] AND P.[ProcessId] = S.[ProcessId] )
				   WHERE P.[VCC] = @VCC 
				         AND S.[Name] IN (SELECT [Name] FROM @Study)
				         
				         
				    --BUSCAR PROCESOS ASINCRONOS SI SE ESTA UTILIZANDO EN ESTUDIOS MAS RECIENTES
				    
				    INSERT INTO @FindInStudy
				    SELECT 
				         DISTINCT [ProcessId]
				    FROM [dbo].[Study]  (NOLOCK)
				    WHERE [VCC] = @VCC 
				          AND [ProcessId] IN (SELECT [ProcessId] FROM #ProcessAsyncToDelete)
				          AND DATEDIFF(DAY,CONVERT(VARCHAR,[CreatedDate],23),@NOW) <= @DAYS
				          
				     
 					--BUSCAR PROCESOS ASINCRONOS QUE NO ESTEN ASIGNADOS A PLANES NI ESTUDIOS
					
			       INSERT INTO #ProcessAsyncToDelete 
				   SELECT 
					     [ProcessId]
				   FROM  [dbo].[ProcessAsyncInteraction] (NOLOCK) 
				   WHERE [VCC] = @VCC 
				         AND [ProcessId] NOT IN (SELECT [ProcessId] FROM #ProcessAsyncToDelete)
				         AND DATEDIFF(DAY,CONVERT(VARCHAR,[CreatedDate],23),@NOW) > @DAYS
				         
				    --ELIMINAR DE #ProcessAsyncToDelete LOS PROCESOS QUE SE ASIGNARON MAS DE UNA VEZ Y RECIENTEMENTE
				    
				     DELETE FROM #ProcessAsyncToDelete WHERE [ProcessId] IN (SELECT [ProcessId] FROM @FindInEvaluationPlan)
				     DELETE FROM #ProcessAsyncToDelete WHERE [ProcessId] IN (SELECT [ProcessId] FROM @FindInStudy)  
				     

                    --BUSCAR INTERACCIONES ASINCRONAS DE LOS PROCESOS QUE QUEDARON PARA SER ELIMINADOS
                    
                    INSERT INTO #AsyncInteractionToDelete
                    SELECT 
                          A.[ID]
                    FROM [dbo].[AsyncInteraction] A (NOLOCK)
                    JOIN [dbo].[ProcessAsyncInteraction] PA (NOLOCK) 
                    ON (A.[VCC] = PA.[VCC] AND A.[ID] = PA.[InteractionId])
                    WHERE A.[VCC] = @VCC 
                          AND  PA.[ProcessId] IN (SELECT [ProcessId] FROM #ProcessAsyncToDelete)
                    
                    --BUSCAR Y QUITAR LAS INTERACCIONES ASINCRONAS QUE FUERON ASIGNADAS A UN NUEVO PROCESO
                    
                     DELETE FROM #AsyncInteractionToDelete 
                     WHERE [ID] IN (
                     SELECT [ID] FROM [dbo].[AsyncInteraction] A (NOLOCK) 
                     JOIN [dbo].[ProcessAsyncInteraction] PA (NOLOCK)
                     ON (A.[VCC] = PA.[VCC] AND A.[ID] = PA.[InteractionId])
                     WHERE A.[VCC] = @VCC
                          AND  PA.[ProcessId] NOT IN (SELECT [ProcessId] FROM #ProcessAsyncToDelete)
                          AND DATEDIFF(DAY,CONVERT(VARCHAR,PA.[CreatedDate],23),@NOW) <= @DAYS
                     )
                     
                     
                    --LISTAR LOS RESULTADOS FINALES
                    
                    SELECT [ID] 'id'     FROM @EvaluationPlan
                    
                    SELECT [Name] 'name' FROM @Study
                  
					SELECT DISTINCT [Name] 'name' FROM #ProcessToDelete
					
					SELECT DISTINCT [ProcessId] 'processId' FROM #ProcessAsyncToDelete
					
					SELECT DISTINCT [ID] 'id',[FileName] 'fileName' FROM #AudioToDelete
					
					SELECT DISTINCT [ID] 'id' FROM #AsyncInteractionToDelete
					
					
					--ELIMINAR LAS TABLAS TEMPORALES
					
					DROP TABLE #ProcessToDelete
					DROP TABLE #AudioToDelete
					DROP TABLE #ProcessAsyncToDelete
					DROP TABLE #AsyncInteractionToDelete
	  
	SET NOCOUNT OFF
END
GO
SET QUOTED_IDENTIFIER OFF 
GO
SET ANSI_NULLS OFF 
GO

GO
